==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/libroccatwidget/roccat_macro_editor_key_sequence_frame.h <==
#ifndef __ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_H__
#define __ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat/roccat.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_TYPE (roccat_macro_editor_key_sequence_frame_get_type())
#define ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_TYPE, RoccatMacroEditorKeySequenceFrame))
#define IS_ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_TYPE))

typedef struct _RoccatMacroEditorKeySequenceFrame RoccatMacroEditorKeySequenceFrame;
typedef struct _RoccatMacroEditorKeySequenceFramePrivate RoccatMacroEditorKeySequenceFramePrivate;

struct _RoccatMacroEditorKeySequenceFrame {
	GtkFrame parent;
	RoccatMacroEditorKeySequenceFramePrivate *priv;
};

GType roccat_macro_editor_key_sequence_frame_get_type(void);

GtkWidget *roccat_macro_editor_key_sequence_frame_new(void);
GtkWidget *roccat_macro_editor_key_sequence_get_action_area(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);

void roccat_macro_editor_key_sequence_frame_set_keystrokes(RoccatMacroEditorKeySequenceFrame *key_sequence_frame, RoccatMacroKeystrokes *keystrokes);
RoccatMacroKeystrokes *roccat_macro_editor_key_sequence_frame_get_keystrokes(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);
void roccat_macro_editor_key_sequence_frame_add_keystroke(RoccatMacroEditorKeySequenceFrame *key_sequence_frame, guint key, guint action, glong abs_time, glong rel_time);
void roccat_macro_editor_key_sequence_frame_clear(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);
gboolean roccat_macro_editor_key_sequence_frame_empty(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);

glong roccat_macro_editor_key_sequence_frame_abs_time(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);

G_END_DECLS

#endif

==> roccat-tools-1.4.0.tar.bz2: roccat-tools-1.4.0/libroccatwidget/roccat_macro_editor_key_sequence_frame.h <==
#ifndef __ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_H__
#define __ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat_macro_keystrokes.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_TYPE (roccat_macro_editor_key_sequence_frame_get_type())
#define ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_TYPE, RoccatMacroEditorKeySequenceFrame))
#define IS_ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_EDITOR_KEY_SEQUENCE_FRAME_TYPE))

typedef struct _RoccatMacroEditorKeySequenceFrame RoccatMacroEditorKeySequenceFrame;
typedef struct _RoccatMacroEditorKeySequenceFramePrivate RoccatMacroEditorKeySequenceFramePrivate;

struct _RoccatMacroEditorKeySequenceFrame {
	GtkFrame parent;
	RoccatMacroEditorKeySequenceFramePrivate *priv;
};

GType roccat_macro_editor_key_sequence_frame_get_type(void);

GtkWidget *roccat_macro_editor_key_sequence_frame_new(void);
GtkWidget *roccat_macro_editor_key_sequence_get_action_area(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);

void roccat_macro_editor_key_sequence_frame_set_keystrokes(RoccatMacroEditorKeySequenceFrame *key_sequence_frame, RoccatMacroKeystrokes *keystrokes);
RoccatMacroKeystrokes *roccat_macro_editor_key_sequence_frame_get_keystrokes(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);
void roccat_macro_editor_key_sequence_frame_add_keystroke(RoccatMacroEditorKeySequenceFrame *key_sequence_frame, guint key, guint action, glong abs_time, glong rel_time);
void roccat_macro_editor_key_sequence_frame_clear(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);
gboolean roccat_macro_editor_key_sequence_frame_empty(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);

glong roccat_macro_editor_key_sequence_frame_abs_time(RoccatMacroEditorKeySequenceFrame *key_sequence_frame);

G_END_DECLS

#endif
